==> nv-wx-srv-eng-1.0.14.tgz: package/index.js <==
const {OD,OASGN,sign_str,add_repr} = require("nv-facutil-basic");
const _url                         = require("url");
const _str                         = require("nv-string-basic");
const _fbsc                        = require("nv-file-basic");
const _S                           = require("nv-server-simple-stream").http.simple;
const _chown_with_name             = require("nv-cli-user").chown_with_name;
const _rrequire                    = require("nv-facutil-rrequire");
const _eng                         = require("./eng");
const _err_bsc                     = require("nv-error-basic");  
const _wxid                        = require("wx-id");


class Srv {
   consts  = _eng.DFLT_CONSTS();
   init_consts(usock,nginx_user,wx_app_id_name,wx_app_secret_name) {
       this.consts.usock        = usock;
       this.consts.nginx_user   = nginx_user; 
       this.wx_app_id_name      = wx_app_id_name;
       this.wx_app_secret_name  = wx_app_secret_name; 
   }
   ////-------------------------------------------------
   user  = null;    //user   globalThis.USER
   oss   = null;    //oss    globalThis.OSS
   redis = null;    //redis  globalThis.REDIS
   cfgdb = null;    //cfg    globalThis.CFG
   //
   init_glb(user,oss,redis,cfgdb) {
        this.user  = user;
        this.oss   = oss;
        this.redis = redis;
        this.cfgdb = cfgdb;
   }
   ////----------------------------------------------
   ////---
   appid  = null;
   secret = null;    
   code2id = (code)=>code;    
   async init_wx() {
       let {wx_app_id_name,wx_app_secret_name} = this.consts;
       let r = await this.cfgdb.select({cond:`seq===0 && name==="${wx_app_id_name}"`});
       console.log("r",r)
       let appid   =  r[0].txt;
       r = await this.cfgdb.select({cond:`seq===0 && name==="${wx_app_secret_name}"`});
       console.log("r",r)
       let secret  =  r[0].txt;    
       this.appid  = appid;
       this.secret = secret;
       this.code2id = _wxid.creat_code2id(appid,secret);
   }
   ////---
   http = null;
   async init_http() {
        let {usock,nginx_user} = this.consts;
        this.http = await _S.creat(usock);
        let Ctor = this.http.constructor;
        add_repr(Ctor,(that)=>that._pipeName);
        _chown_with_name(usock,nginx_user);
   }
   ////---
   handle_dict = {};
   set_handle(route,afunc,reload=false) {
       if(afunc === undefined) {
           let p = _str.trim(route,"/");
           let arr = p.split("/");
           p = arr.join("-");
           if(reload) {
                this.handle_dict[route] = _eng.DFLT_404_HANDLE;
                _rrequire.unrequire("./route/"+p);
           } else {}
           this.handle_dict[route] = require("./route/"+p);
       } else {
           this.handle_dict[route] = afunc;
       }
   } 
   ////---    
   async get_openid(cubody) {
        let {code}        = cubody;
        if(code===undefined) {
            return([false,"code不能为空"])
        } else {
            code = String(code); 
            if(code.length===0) {
                return([false,"code不能为空"])
            } else { 
                let [cond,openid] = await this.code2id(code);
                return([cond,openid])
            }
        }
   }    
   async change_wx_cfg() {
        try {
            await this.init_wx(); 
            return([true,null])
        } catch(err) {
            return([false,_err_bsc.to_json(err)]) 
        }
   }     
}


const DFLT_CFG = ()=>({
   user:globalThis.USER,
   oss:globalThis.OSS,
   redis:globalThis.REDIS,
   cfgdb:globalThis.CFG,
   validate:_eng.DFLT_VALIDATE,
   ////---- wx_app_id_name  wx_app_secret_name usock nginx_user 
   ..._eng.DFLT_CONSTS(),
   ////
});

async function creat(cfg=DFLT_CFG()) {
    let ncfg = OASGN(DFLT_CFG(),cfg);
    //--enable service:--
    let srv = new Srv();
    //consts
    {
        let {usock,nginx_user,wx_app_id_name,wx_app_secret_name} = ncfg;  
        srv.init_consts(usock,nginx_user,wx_app_id_name,wx_app_secret_name);  
    }
    //validate
    srv.validate = ncfg.validate;
    // global
    srv.init_glb(ncfg.user,ncfg.oss,ncfg.redis,ncfg.cfgdb);
    // http-server
    srv.init_http();
    // wx
    await srv.init_wx();
    //--add handle  最后接
    for(let route in  _eng.ROUTED()) {  //  route:api_name
       srv.set_handle(route)
    }
    //// --
    srv.http.handler_ = async (req,res) => {
        let D      = await _S.extract_req(req);
        ////--------------------patch-----------------------------
        D.pathname = _url.parse(D.path).pathname;
        ////-----------------------------------------------------
        let afunc = srv.handle_dict[D.path]??srv.handle_dict[D.pathname];
        if(afunc===undefined) {
            return(await _eng.DFLT_ROUTE_NOT_EXIST(D,res,srv))
        } else {
            return(await afunc(D,res,srv));
        }
    }
    //
    return(srv)
}

module.exports = {
   Srv,
   DFLT_CFG, 
   creat, 
}

==> nv-wx-srv-eng-1.0.19.tgz: package/index.js <==
const {OD,OASGN,sign_str,add_repr} = require("nv-facutil-basic");
const _url                         = require("url");
const _str                         = require("nv-string-basic");
const _fbsc                        = require("nv-file-basic");
const _S                           = require("nv-server-simple-stream").http.simple;
const _chown_with_name             = require("nv-cli-user").chown_with_name;
const _rrequire                    = require("nv-facutil-rrequire");
const _eng                         = require("./eng");
const _err_bsc                     = require("nv-error-basic");  
const _wxid                        = require("wx-id");
const _wxhb                        = require("wx-hongbao-pay"); 

class Srv {
   consts  = _eng.DFLT_CONSTS();
   init_consts(usock,nginx_user,wx_app_id_name,wx_app_secret_name) {
       this.consts.usock        = usock;
       this.consts.nginx_user   = nginx_user; 
       this.wx_app_id_name      = wx_app_id_name;
       this.wx_app_secret_name  = wx_app_secret_name; 
   }
   ////-------------------------------------------------
   user  = null;    //user   globalThis.USER
   oss   = null;    //oss    globalThis.OSS
   redis = null;    //redis  globalThis.REDIS
   cfgdb = null;    //cfg    globalThis.CFG
   //
   init_glb(user,oss,redis,cfgdb) {
        this.user  = user;
        this.oss   = oss;
        this.redis = redis;
        this.cfgdb = cfgdb;
   }
   ////----------------------------------------------
   ////---
   appid  = null;
   secret = null;    
   code2id = (code)=>code;   
   hongbao_retry_min_intv = 1000;
   hongbao_send_freq = [30,1000];
   send_hb = (appid,secret,hongbao_retry_min_intv,hongbao_send_freq)=>[null/*reqj*/,null/*resj*/]; 
   // 
   async init_wx() {
       /////------------------------------------------------------------
       let {wx_app_id_name,wx_app_secret_name} = this.consts;
       let r = await this.cfgdb.select({cond:`seq===0 && name==="${wx_app_id_name}"`});
       let appid   =  r[0].txt;
       r = await this.cfgdb.select({cond:`seq===0 && name==="${wx_app_secret_name}"`});
       let secret  =  r[0].txt;    
       this.appid  = appid;
       this.secret = secret;
       this.code2id = _wxid.creat_code2id(appid,secret);
       ////----------------------------------------------------------
       let {wx_hongbao_retry_min_intv_name,wx_hongbao_send_freq_name} = this.consts;
       r = await this.cfgdb.select({cond:`seq===0 && name==="${wx_hongbao_retry_min_intv_name}"`});
       let hongbao_retry_min_intv   =  r[0].jsn;
       this.hongbao_retry_min_intv  = hongbao_retry_min_intv;
       r = await this.cfgdb.select({cond:`seq===0 && name==="${wx_hongbao_send_freq_name}"`});
       let hongbao_send_freq  =  r[0].jsn;       
       this.hongbao_send_freq  = hongbao_send_freq;
       this.send_hb = _wxhb.creat_send_hb(
           appid,secret,
           hongbao_retry_min_intv,hongbao_send_freq,
           this.redis.dflt_/*for min intv ctrl*/  
       );
   }
   ////---
   http = null;
   async init_http() {
        let {usock,nginx_user} = this.consts;
        this.http = await _S.creat(usock);
        let Ctor = this.http.constructor;
        add_repr(Ctor,(that)=>that._pipeName);
        _chown_with_name(usock,nginx_user);
   }
   ////---
   handle_dict = {};
   set_handle(route,afunc,reload=false) {
       if(afunc === undefined) {
           let p = _str.trim(route,"/");
           let arr = p.split("/");
           p = arr.join("-");
           if(reload) {
                this.handle_dict[route] = _eng.DFLT_404_HANDLE;
                _rrequire.unrequire("./route/"+p);
           } else {}
           this.handle_dict[route] = require("./route/"+p);
       } else {
           this.handle_dict[route] = afunc;
       }
   } 
   ////---    
   async get_openid(cubody) {
        let {code}        = cubody;
        if(code===undefined) {
            return([false,"code不能为空"])
        } else {
            code = String(code); 
            if(code.length===0) {
                return([false,"code不能为空"])
            } else { 
                let [cond,openid] = await this.code2id(code);
                console.log([cond,openid])
                return([cond,openid])
            }
        }
   }
   async send_hongbao(cudata) {
        //此函数被query模块调用 使用后插入query数据库
        if(cudata) {
            let [reqj,resj] = this.send_hb(cudata);
            if(true) { 
                return([true,resj])
            } else {
                return([false,resj])
            }
        } else {
            return([false,"数据参数有误"])
        }
   }    
   async change_wx_cfg() {
        try {
            await this.init_wx(); 
            return([true,null])
        } catch(err) {
            return([false,_err_bsc.to_json(err)]) 
        }
   }     
}


const DFLT_CFG = ()=>({
   user:globalThis.USER,
   oss:globalThis.OSS,
   redis:globalThis.REDIS,
   cfgdb:globalThis.CFG,
   validate:_eng.DFLT_VALIDATE,
   ////---- wx_app_id_name  wx_app_secret_name usock nginx_user 
   ..._eng.DFLT_CONSTS(),
   ////
});


async function creat(cfg=DFLT_CFG()) {
    let dflt = DFLT_CFG();
    let ncfg = OASGN(dflt,cfg);
    //--enable service:--
    let srv = new Srv();
    //consts
    {
        let {usock,nginx_user,wx_app_id_name,wx_app_secret_name} = ncfg;  
        srv.init_consts(usock,nginx_user,wx_app_id_name,wx_app_secret_name);  
    }
    //validate
    srv.validate = ncfg.validate;
    // global
    srv.init_glb(ncfg.user,ncfg.oss,ncfg.redis,ncfg.cfgdb);
    // http-server
    srv.init_http();
    // wx
    await srv.init_wx();
    //--add handle  最后接
    for(let route in  _eng.ROUTED()) {  //  route:api_name
       srv.set_handle(route)
    }
    //// --
    srv.http.handler_ = async (req,res) => {
        let D      = await _S.extract_req(req);
        ////--------------------patch-----------------------------
        D.pathname = _url.parse(D.path).pathname;
        ////-----------------------------------------------------
        let afunc = srv.handle_dict[D.path]??srv.handle_dict[D.pathname];
        if(afunc===undefined) {
            return(await _eng.DFLT_ROUTE_NOT_EXIST(D,res,srv))
        } else {
            return(await afunc(D,res,srv));
        }
    }
    //
    return(srv)
}

module.exports = {
   Srv,
   DFLT_CFG, 
   creat, 
}
